# @(#)10  1.8 src/cmdline/staging/scripts/import_federation.py, amws.cmdline, fim611, 060921a 9/18/06 16:18:27
# (C) Copyright International Business Machines Corporation 2005. All rights
# reserved.  U.S. Government Users Restricted Rights -- Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 
from com.tivoli.am.fim.middlemanager.ssps import FederationManager, ConfigurationParameters, Partner
from fim_base import read_properties_file, commit_session, prepare_mgr_objs
from fed_utils import get_federation, import_federation
from domain_utils import is_domain_present
from com.tivoli.am.fim.logging import FIMLoggerFactory
from com.tivoli.am.fim.logging import FIMLogger
from com.tivoli.am.fim.logging import FIMLevel
from com.tivoli.am.fim.i18n.msgs import CmdLineMessages
from jarray import array
from java.lang import Object
from com.tivoli.am.fim.logging import FIMLoggerConstants

# Set up FIMLogger
component_name = "StagingTools"
script_name = "import_federation.py"
method_name = script_name
class_name = "com.tivoli.am.fim.cmdline." + script_name[0:-3]
FIMLoggerFactory.enableStdout(FIMLevel.ALL)
FIMLoggerFactory.setPreferredFIMLoggerImpl(FIMLoggerConstants.FIMLOGGER_BASE_IMPL)
log = FIMLoggerFactory.getFIMLogger(component_name, class_name, CmdLineMessages.CLASS_NAME)

def usage():
    inserts = array([script_name],Object)
    log.logMessage(FIMLevel.INFO, method_name, CmdLineMessages.usage_import_federation, \
        inserts)
    raise SystemExit
    
if __name__ == 'main':

    if len(sys.argv) < 4:
        usage()
    elif len(sys.argv)==4:
        src_props_file = sys.argv[0]
        targ_props_file = sys.argv[1]
        user_props_file = sys.argv[2]
        fed_name = sys.argv[3]
        import_partners = None
    elif len(sys.argv)==5:
        src_props_file = sys.argv[0]
        targ_props_file = sys.argv[1]
        user_props_file = sys.argv[2]
        fed_name = sys.argv[3]
        if sys.argv[4] != "-import_partners":
            usage()
        else:
            import_partners = sys.argv[4]
    else:
        usage()
        
    domain_props = read_properties_file(src_props_file)
    if not is_domain_present(domain_props):
        raise SystemExit          
    
    # Get the source federation object and federation manager
    (src_fed, src_fed_mgr) = get_federation(fed_name, src_props_file)

    if not src_fed:
        inserts = array([fed_name], Object)
        log.logMessage(FIMLevel.INFO, method_name, \
            CmdLineMessages.federation_does_not_exist, inserts)
        raise SystemExit

    # Get the target federation manager
    targ_props = read_properties_file(targ_props_file)
    if not is_domain_present(targ_props):
        raise SystemExit    
    (targ_fed_mgr, targ_sec_tok_mgr) = prepare_mgr_objs(targ_props, \
        "import_federations_and_partners")    

    # Get user-defined properties for the federation 
    user_props = read_properties_file(user_props_file)

    # If the user properties file sets DisplayName, then that will be
    # the name of the new federation, so we have to set the name here
    # before checking whether a federation by that name already exists. 
    if user_props.has_key("DisplayName"):
        old_fed_name = fed_name
        new_fed_name = user_props["DisplayName"]
    else:
        old_fed_name = new_fed_name = fed_name

    if targ_fed_mgr.hasFederationDisplayName(new_fed_name):
        # Cannot import a federation with the same name
        inserts = array([new_fed_name, targ_props["Domain"]], Object)
        log.logMessage(FIMLevel.INFO, method_name, \
            CmdLineMessages.federation_already_exists_in_domain, inserts)
        raise SystemExit

    import_federation(src_fed, targ_fed_mgr, targ_sec_tok_mgr, user_props, \
        old_fed_name, import_partners)
         
    if targ_fed_mgr.hasFederationDisplayName(new_fed_name):
        inserts = array([new_fed_name], Object)
        log.logMessage(FIMLevel.INFO, method_name, \
            CmdLineMessages.imported_federation_successfully, inserts)
    else:
        inserts = array([old_fed_name], Object)
        log.logMessage(FIMLevel.WARNING, method_name, \
            CmdLineMessages.unable_to_import_federation, inserts)
        raise SystemExit
        
    raise SystemExit
    
